@@ -209,8 +209,9 @@ def infer_best_package(package_name: str,
         message = (
             "See below for the error message and instruction.\n\n\n" +
             "************************************************************************\n" +
-            "ERROR: Unable to detect NVIDIA CUDA Toolkit installation\n" +
-            f"ERROR: Explicitly specify CUDA version by: `pip install {PACKAGE_NAME}` run\n" +
+            "ERROR: Unable to detect NVIDIA CUDA Toolkit installation.\n" +
+            "ERROR: If CUDA Toolkit is not installed, please install it first.\n" + 
+            "ERROR: If CUDA Toolkit is installed but not detected, please explicitly specify the version and run\n" +
             f"ERROR: `pip install {PACKAGE_NAME}-cuXX`, with XX being the major\n" +
             "ERROR: version of your CUDA Toolkit installation.\n" +
             "************************************************************************\n\n"
